#
# spec file for package dualsensectl
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           dualsensectl
Version:        0.7
Release:        3.1
Summary:        Tool for controlling PlayStation 5 DualSense controllers on Linux
License:        GPL-2.0
URL:            https://github.com/nowrep/%{name}
Source0:        https://github.com/nowrep/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        https://raw.githubusercontent.com/nowrep/%{name}/refs/heads/main/README.md
Source2:        https://raw.githubusercontent.com/nowrep/%{name}/refs/heads/main/LICENSE

BuildRequires:  gcc
BuildRequires:  meson
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(hidapi-hidraw)
BuildRequires:  pkgconfig(hidapi-libusb)
BuildRequires:  pkgconfig(systemd)
BuildRequires:  pkgconfig(udev)

%description
DualSense Control [DualSenseCTL] is a tool for controlling Sony PlayStation 5 DualSense controllers on Linux.

%prep
%autosetup -p1

%build
%meson
%meson_build

%install
%meson_install

install -Dm644 "%{_builddir}/%{name}-%{version}/completion/%{name}" -t "%{buildroot}/%{_datadir}/bash-completion/completions/"
install -Dm644 "%{_builddir}/%{name}-%{version}/completion/_%{name}"   "%{buildroot}/%{_datadir}/zsh/site-functions/%{name}"

%files
%license "LICENSE"

%doc     "README.md"

      %{_bindir}/%{name}

%dir "%{_datadir}/bash-completion/"
%dir "%{_datadir}/bash-completion/completions/"
     "%{_datadir}/bash-completion/completions/%{name}"

%dir "%{_datadir}/zsh/"
%dir "%{_datadir}/zsh/site-functions/"
     "%{_datadir}/zsh/site-functions/%{name}"

%changelog
* Mon Mar  3 2025 Martin von Reichenberg <martin.von.reichenberg@proton.me>
- REBUILD due to RPMLINT errors:
  `dualsensectl.x86_64: E: standard-dir-owned-by-package /usr/bin`
  `dualsensectl.x86_64: E: standard-dir-owned-by-package /usr/share`
* Wed Feb 19 2025 Martin von Reichenberg <martin.von.reichenberg@proton.me>
- Update to the latest upstream stable version - 0.7
  * Switch to Meson build system
  * Add pulse option to microphone-led
  * Add instant flag to player-leds
  * Add led-brightness command
  * Add microphone-mode command
* Mon Aug 19 2024 Martin von Reichenberg <martin.von.reichenberg@proton.me>
- Added support for DualSense Edge
* Sat May  4 2024 Martin von Reichenberg <martin.von.reichenberg@proton.me>
- Defattr not needed after explicitly mentioned directories (%%dir) within %%files section which OBS gladly complains about
- Now using: osc service mr download_files instead of manually downloaded files using GUI
- %%{?_smp_mflags} is redundant, therefore unneeded - I overlooked
  :-)
* Sun Mar 31 2024 Martin von Reichenberg <martin.von.reichenberg@proton.me>
- Update to new upstream release version 0.5
  * Fix crash when setting device without command
  * Show more values in info command
  * Don't check Connected property in power-off command
* Sat Nov  4 2023 Martin von Reichenberg <martin.von.reichenberg@proton.me>
- Update to new upstream release version 0.4
  * Added `speaker` `volume` `attenuation` and `trigger` commands
* Thu Oct 12 2023 Martin von Reichenberg <martin.von.reichenberg@proton.me>
- Update to new upstream release version 0.3
  * Added speaker volume attenuation and trigger commands
  * Added a new monitoring command for scheduling/adjusting certain (even multiple) events
  * Added a new `dualsense -d DEVICE` option for listing of multiple connected devices
  and their identification
  * Fixed battery level status not showing correct percents (%%) when plugged in
* Thu Jun 23 2022 Fabio Pesari <fpesari@tuxfamily.org>
- Update to new upstream release version 0.2
  * Initial upload of `dualsensectl` package into Open Build Service
